@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package CPAN::Meta;
 
-our $VERSION = '2.150002'; # TRIAL
+our $VERSION = '2.150003'; # TRIAL
 
 #pod =head1 SYNOPSIS
 #pod
@@ -591,6 +591,10 @@ sub as_struct {
 #pod both cases, the same rules are followed as in the C<save()> method for choosing
 #pod a serialization backend.
 #pod
+#pod The serialized structure will include a C<x_serialization_backend> entry giving
+#pod the package and version used to serialize.  Any existing key in the given
+#pod C<$meta> object will be clobbered.
+#pod
 #pod =cut
 
 sub as_string {
@@ -610,10 +614,14 @@ sub as_string {
   my ($data, $backend);
   if ( $version ge '2' ) {
     $backend = Parse::CPAN::Meta->json_backend();
+    local $struct->{x_serialization_backend} = sprintf '%s version %s',
+      $backend, $backend->VERSION;
     $data = $backend->new->pretty->canonical->encode($struct);
   }
   else {
     $backend = Parse::CPAN::Meta->yaml_backend();
+    local $struct->{x_serialization_backend} = sprintf '%s version %s',
+      $backend, $backend->VERSION;
     $data = eval { no strict 'refs'; &{"$backend\::Dump"}($struct) };
     if ( $@ ) {
       croak $backend->can('errstr') ? $backend->errstr : $@
@@ -642,7 +650,7 @@ CPAN::Meta - the distribution metadata for a CPAN dist
 
 =head1 VERSION
 
-version 2.150002
+version 2.150003
 
 =head1 SYNOPSIS
 
@@ -857,6 +865,10 @@ JSON.  For C<version> less than 2, the string will be serialized as YAML.  In
 both cases, the same rules are followed as in the C<save()> method for choosing
 a serialization backend.
 
+The serialized structure will include a C<x_serialization_backend> entry giving
+the package and version used to serialize.  Any existing key in the given
+C<$meta> object will be clobbered.
+
 =head1 STRING DATA
 
 The following methods return a single value, which is the value for the
@@ -995,7 +1007,7 @@ L<CPAN::Meta::Validator>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/Perl-Toolchain-Gang/CPAN-Meta/issues>.
+at L<https://github.com/Perl-Toolchain-Gang/cpan-meta/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -1003,9 +1015,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/Perl-Toolchain-Gang/CPAN-Meta>
+L<https://github.com/Perl-Toolchain-Gang/cpan-meta>
 
-  git clone https://github.com/Perl-Toolchain-Gang/CPAN-Meta.git
+  git clone https://github.com/Perl-Toolchain-Gang/cpan-meta.git
 
 =head1 AUTHORS
 
